ChatController class
Constructors
Properties
-
chatController
→ StreamController<
List< ChatMessageData> > -
final
-
chatHistory
→ List<
ChatMessageData> -
final
- controller → ScrollController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
modelMap
→ Map<
String, String> -
final
-
models
→ List<
String> -
final
- ollama → Ollama
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedModel
→ ValueNotifier<
String> -
final
- textController → TextEditingController
-
final
- tinyllama ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
submitQuestion(
String question) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
updateChat(
ChatMessageData message) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited